@@ -6,10 +6,10 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use Moo;
-extends 'Chart::Kaleido::Base';
+extends 'Chart::Kaleido';
 
 use File::ShareDir;
 use JSON;
@@ -25,18 +25,6 @@ use namespace::autoclean;
 my @text_formats = qw(svg json eps);
 
 
-has '+all_formats' =>
-  ( default => sub { [qw(png jpg jpeg webp svg pdf eps json)] } );
-
-has '+scope_name' => ( default => 'plotly' );
-
-has '+scope_flags' =>
-  ( default => sub { [qw(plotlyjs mathjax topojson mapbox_access_token)] }, );
-
-has '+base_args' =>
-  ( default => sub { [ qw(plotly --disable-gpu) ] } );
-
-
 has plotlyjs => (
     is      => 'ro',
     isa     => (Str | Undef),
@@ -63,6 +51,19 @@ has mapbox_access_token => (
 );
 
 
+has '+all_formats' =>
+  ( default => sub { [qw(png jpg jpeg webp svg pdf eps json)] } );
+
+has '+scope_name' => ( default => 'plotly' );
+
+has '+scope_flags' =>
+  ( default => sub { [qw(plotlyjs mathjax topojson mapbox_access_token)] }, );
+
+has '+base_args' =>
+  ( default => sub { [ qw(plotly --disable-gpu) ] } );
+
+
+
 sub transform {
     my $self = shift;
     state $check = compile_named_oo(
@@ -150,7 +151,7 @@ Chart::Kaleido::Plotly - Export static images of Plotly charts using Kaleido
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -173,10 +174,6 @@ This class wraps the "plotly" scope of plotly's kaleido command.
 
 =head2 timeout
 
-=head2 all_formats
-
-All supported formats.
-
 =head2 plotlyjs
 
 Path to plotly js file.
@@ -188,6 +185,10 @@ Default value is plotly js bundled with L<Chart::Ploly>.
 
 =head2 mapbox_access_token
 
+=head2 all_formats
+
+Read-only class attribute. All supported formats.
+
 =head1 METHODS
 
 =head2 transform
@@ -212,7 +213,7 @@ Save static image to file.
 L<https://github.com/plotly/Kaleido>
 
 L<Chart::Plotly>,
-L<Chart::Kaleido::Base>,
+L<Chart::Kaleido>,
 L<Alien::Plotly::Kaleido>
 
 =head1 AUTHOR
